"""Runtime dependency checks."""

from shutil import which

from .app import RootlessApp


def check_requirements(app: RootlessApp) -> bool:
    """Check if all runtime requirements are satisfied."""
    requirements = [
        app.config.pandoc,
        app.config.dot,
    ]
    return all(map(which, requirements))



from pathlib import Path
import setuptools

setuptools.setup(
    name="slipbox",
    version="0.19.0a2",
    author="Levi Gruspe",
    author_email="mail.levig@gmail.com",
    description="Static site generator for Zettelkasten notes",
    long_description=Path("README.md").read_text(),
    long_description_content_type="text/markdown",
    url="https://github.com/lggruspe/slipbox",
    packages=setuptools.find_packages(),
    package_data={
        "slipbox": [
            "data/*",
            "data/es5/*/*/*/*/*",
            "data/favicons/*",
            "data/svg/*/*.svg",
            "migrations/*.sql",
            "templates/*",
        ]
    },
    classifiers=[
        "Environment :: Console",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
    install_requires=[
        "networkx>=2.5.1",
        "pydot>=1.4.2",
        "pyquery>=1.4.3",
    ],
    python_requires=">=3.7",
    entry_points={
        "console_scripts": [
            "slipbox=slipbox.__main__:main"
        ]
    }
)



"""Slipbox CLI parser."""

from argparse import ArgumentParser, RawDescriptionHelpFormatter
import typing as t


def parse_args(argv: t.Optional[t.Sequence[str]] = None) -> t.Dict[str, t.Any]:
    """Returns dict of command-line options and arguments.

    Name of subcommand can be accessed using the key: "(command)".
    """
    epilog = """
  build     Build website.
  check     Check for isolated notes and invalid links.
  formats   List supported input file formats.
  info      Show note info.
  init      Initialize notes directory.
  new       Get unused note IDs.
"""

    parser = ArgumentParser(
        prog="slipbox",
        description="Generate a static website from your notes.",
        formatter_class=RawDescriptionHelpFormatter,
        epilog=epilog,
    )
    parser.add_argument(
        "-v",
        "--version",
        action="store_true",
        help="show version number and exit",
    )

    # Add subcommands
    subparsers = parser.add_subparsers(
        title="commands",
        dest="(command)",
    )

    subparser = subparsers.add_parser("build", description="Build website.")
    subparser.add_argument(
        "--no-output",
        action="store_false",
        dest="output",
        help="update database only; do not generate site in output directory",
    )

    subparsers.add_parser(
        "check",
        description="Check for isolated notes and invalid links.",
    )

    subparser = subparsers.add_parser("info", description="Show note info.")
    subparser.add_argument("note_id", type=int)

    subparsers.add_parser(
        "formats",
        description="List supported input file formats.",
    )

    subparser = subparsers.add_parser(
        "init",
        description="Initialize notes directory.",
    )
    subparser.add_argument("-q", "--quiet", action="store_true")

    subparser = subparsers.add_parser(
        "new",
        description="Get unused note IDs.",
    )
    subparser.add_argument(
        "-n",
        type=int,
        default=1,
        help="number of note IDs to generate",
    )
    return vars(parser.parse_args(argv))


__all__ = ["parse_args"]
